@@ -12,7 +12,7 @@ from copy import deepcopy
 import re
 import sys
 
-from deepops import deepremoveitems, deepdiff, deepget
+from deepops import deepremoveitems, deepmerge, deepdiff, deepsetdefault, deepget
 import yaml
 
 
@@ -418,6 +418,36 @@ class DiffConfig:
         return None
 
 
+    def _changes_begin(self):
+        """This method returns a head (beginning) for a generated
+        changes configuration file as an iterable of strings.
+
+        In the abstract class, it returns None (which does not add
+        anything) but, in child classes it may return a beginning line
+        or similar.
+
+        Note that if there are no changes, this will not be included in
+        an otherwise empty file.
+        """
+
+        return []
+
+
+    def _changes_end(self):
+        """This method returns a tail (ending) for a generated changes
+        configuration file as an iterable of strings.
+
+        In the abstract class, it returns None (which does not add
+        anything) but, in child classes it may return an 'end' line or
+        similar.
+
+        Note that if there are no changes, this will not be included in
+        an otherwise empty file.
+        """
+
+        return []
+
+
     def init_excludes(self):
         """This method initialises the excludes dictionary.  In the base
         class, it the resets it to an empty dictionary, but child
@@ -426,7 +456,7 @@ class DiffConfig:
         changed.
 
         It is normally only called by the constructor but can be called
-        later, to clear the exlcludes list before adding more (if
+        later, to clear the excludes list before adding more (if
         required).
         """
 
@@ -480,6 +510,38 @@ class DiffConfig:
                 self.add_exclude(l)
 
 
+    def read_excludes_yaml(self, filename, path=None):
+        """Read a list of exclude items from a YAML file and add them to
+        the excludes dictionary.
+
+        The path parameter specifies the key in the dictionary where the
+        excludes are specified.  This is useful if the dictionary is
+        also contains other data (such as the inventory).  The path is
+        specified a list of keys, separated by colons.  If the path is
+        None or otherwise False, the top of the dictionary is used.
+        """
+
+
+        # try to read in the YAML excludes file
+
+        try:
+            f = yaml.safe_load(open(filename))
+
+        except yaml.parser.ParserError as exception:
+            raise ValueError("failed parsing YAML excludes file: %s: %s"
+                                 % (filename, exception))
+
+
+        # if no path was specified, just use the entire file, else get
+        # the key given
+
+        if not path:
+            deepmerge(self._excludes, f)
+        else:
+            deepmerge(self._excludes,
+                      deepget(f, *path.split(":"), default_error=True))
+
+
     def get_excludes(self):
         "This method just returns the excludes dictionary."
 
@@ -713,8 +775,13 @@ class DiffConfig:
             if self._debug_convert:
                 print(file=sys.stderr)
 
+        # if nothing was generated, just return nothing
+
+        if not changes:
+            return None
+
 
         # return the change lines concatenated into a big, multiline
-        # string
+        # string, along with the begin and end blocks
 
-        return "\n".join(changes)
+        return "\n".join(self._changes_begin() + changes + self._changes_end())
