@@ -300,6 +300,62 @@ class _Cvtr_Int_IP6Addr(DiffConvert):
 _cvtrs.append(_Cvtr_Int_IP6Addr)
 
 
+class _Cvtr_Int_IPIGMPVer(DiffConvert):
+    path = "interface", None, "ip-igmp-ver"
+
+    def remove(self, cfg, diff, args):
+        name, = args
+        return "interface " + name, " no ip igmp version"
+
+    def update(self, cfg, diff, args):
+        name, = args
+        return "interface " + name, " ip igmp version " + diff
+
+_cvtrs.append(_Cvtr_Int_IPIGMPVer)
+
+
+class _Cvtr_Int_IPMcastBdry(DiffConvert):
+    path = "interface", None, "ip-mcast-bdry"
+
+    def remove(self, cfg, diff, args):
+        name, = args
+        return "interface " + name, " no ip multicast boundary"
+
+    def update(self, cfg, diff, args):
+        name, = args
+        return "interface " + name, " ip multicast boundary " + diff
+
+_cvtrs.append(_Cvtr_Int_IPMcastBdry)
+
+
+class _Cvtr_Int_IPPIMMode(DiffConvert):
+    path = "interface", None, "ip-pim", "mode"
+
+    def remove(self, cfg, diff, args):
+        name, = args
+        return "interface " + name, " no ip pim " + cfg
+
+    def update(self, cfg, diff, args):
+        name, = args
+        return "interface " + name, " ip pim " + diff
+
+_cvtrs.append(_Cvtr_Int_IPPIMMode)
+
+
+class _Cvtr_Int_IPPIMBSRBdr(DiffConvert):
+    path = "interface", None, "ip-pim", "bsr-border"
+
+    def remove(self, cfg, diff, args):
+        name, = args
+        return "interface " + name, " no ip pim bsr-border"
+
+    def update(self, cfg, diff, args):
+        name, = args
+        return "interface " + name, " ip pim bsr-border"
+
+_cvtrs.append(_Cvtr_Int_IPPIMBSRBdr)
+
+
 class _Cvtr_Int_ServPol(DiffConvert):
     path = "interface", None, "service-policy"
 
@@ -379,7 +435,7 @@ class _Cvtr_Int_SwPortTrkNtv(DiffConvert):
             return None
 
         return ("interface " + name,
-                " switchport trunk native vlan " + self.get_ext(diff))
+                " switchport trunk native vlan %d" % self.get_ext(diff))
 
 _cvtrs.append(_Cvtr_Int_SwPortTrkNtv)
 
