@@ -650,11 +650,11 @@ _cmds.append(_Cmd_Int_HlprAddr)
 
 
 class _Cmd_Int_IPAccGrp(_CmdContext_Int):
-    cmd = r"ip access-group (?P<access_group>\S+) (?P<direction>in|out)"
+    cmd = r"ip access-group (?P<acl>\S+) (?P<direction>in|out)"
 
     def action(self, groups, cfg, params):
         cfg.setdefault("ip-access-group", {})[groups["direction"]] = (
-            groups["access_group"])
+            groups["acl"])
 
 _cmds.append(_Cmd_Int_IPAccGrp)
 
@@ -689,6 +689,42 @@ class _Cmd_Int_IP6Addr(_CmdContext_Int):
 _cmds.append(_Cmd_Int_IP6Addr)
 
 
+class _Cmd_Int_IPIGMPVer(_CmdContext_Int):
+    cmd = r"ip igmp version (?P<version>\S+)"
+
+    def action(self, groups, cfg, params):
+        cfg["ip-igmp-ver"] = groups["version"]
+
+_cmds.append(_Cmd_Int_IPIGMPVer)
+
+
+class _Cmd_Int_IPMcastBdry(_CmdContext_Int):
+    cmd = r"ip multicast boundary (?P<acl>\S+)"
+
+    def action(self, groups, cfg, params):
+        cfg["ip-mcast-bdry"] = groups["acl"]
+
+_cmds.append(_Cmd_Int_IPMcastBdry)
+
+
+class _Cmd_Int_IPPIMMode(_CmdContext_Int):
+    cmd = r"ip pim (?P<mode>(sparse|dense|sparse-dense)-mode)"
+
+    def action(self, groups, cfg, params):
+        cfg.setdefault("ip-pim", {})["mode"] = groups["mode"]
+
+_cmds.append(_Cmd_Int_IPPIMMode)
+
+
+class _Cmd_Int_IPPIMBSRBdr(_CmdContext_Int):
+    cmd = r"ip pim bsr-border"
+
+    def action(self, groups, cfg, params):
+        cfg.setdefault("ip-pim", {})["bsr-border"] = True
+
+_cmds.append(_Cmd_Int_IPPIMBSRBdr)
+
+
 class _Cmd_Int_ServPol(_CmdContext_Int):
     cmd = r"service-policy (?P<policy>.+)"
 
